==> nosql-database_24.4.zip: nosql-database_24.4_20241213/content/changelog/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Upgrade Requirements",
                    "href":"upgrade-requirements.html"
                },
                {
                    "title":"Changes in 24.4.9",
                    "href":"changes-24.4.9.html"
                },
                {
                    "title":"Changes in 24.3.9",
                    "href":"changes-24.3.9.html"
                },
                {
                    "title":"Changes in 24.1.15",
                    "href":"changes-24.1.15.html"
                },
                {
                    "title":"Changes in 23.3.30",
                    "href":"changes-23.3.29.html"
                },
                {
                    "title":"Changes in 23.1.21",
                    "href":"changes-23.1.21.html"
                },
                {
                    "title":"Changes in 22.3.16",
                    "href":"changes-22.3.16.html"
                },
                {
                    "title":"Changes in 22.2.12",
                    "href":"changes-22.2.12.html"
                },
                {
                    "title":"Changes in 22.1.22",
                    "href":"changes-22.1.22.html"
                },
                {
                    "title":"Changes in 22.1.16",
                    "href":"changes-22.1.16.html"
                },
                {
                    "title":"Changes in 21.2.46",
                    "href":"changes-21.2.46.html"
                },
                {
                    "title":"Changes in 21.2.29",
                    "href":"changes-21.2.29.html"
                },
                {
                    "title":"Changes in 21.2.19",
                    "href":"changes-21.2.19.html"
                },
                {
                    "title":"Changes in 21.1.12",
                    "href":"changes-21.1.12.html"
                },
                {
                    "title":"Changes in 20.3.26",
                    "href":"changes-20.3.26.html"
                },
                {
                    "title":"Changes in 20.3.17",
                    "href":"changes-20.3.17.html"
                },
                {
                    "title":"Changes in 20.2.17",
                    "href":"changes-20.2.17.html"
                },
                {
                    "title":"Changes in 20.2.16",
                    "href":"changes-20.2.16.html"
                },
                {
                    "title":"Changes in 20.1.20",
                    "href":"changes-20.1.20.html"
                },
                {
                    "title":"Changes in 20.1.16",
                    "href":"changes-20.1.16.html"
                },
                {
                    "title":"Changes in 20.1.15",
                    "href":"changes-20.1.15.html"
                },
                {
                    "title":"Changes in 19.5.30",
                    "href":"changes-19.5.30.html"
                },
                {
                    "title":"Changes in 19.5.19",
                    "href":"changes-19.5.19.html"
                },
                {
                    "title":"Changes in 19.5.16",
                    "href":"changes-19.5.16.html"
                },
                {
                    "title":"Changes in 19.3.12",
                    "href":"changes-19.3.12.html"
                },
                {
                    "title":"Changes in 19.1.10",
                    "href":"changes-19.1.10.html"
                },
                {
                    "title":"Changes in 19.1.8",
                    "href":"changes-19.1.8.html"
                },
                {
                    "title":"Changes in 18.3.11",
                    "href":"changes-18.3.11.html"
                },
                {
                    "title":"Changes in 18.3.10",
                    "href":"changes-18.3.10.html"
                },
                {
                    "title":"Changes in 18.3.9",
                    "href":"changes-18.3.9.html"
                },
                {
                    "title":"Changes in 18.1.20",
                    "href":"changes-18.1.20.html"
                },
                {
                    "title":"Changes in 18.1.16",
                    "href":"changes-18.1.16.html"
                },
                {
                    "title":"Changes in 18.1.13",
                    "href":"changes-18.1.13.html"
                }
            ]
        }
    ]
});

==> nosql-database_25.3.zip: nosql-database_25.3_20251015/content/changelog/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Upgrade Requirements",
                    "href":"upgrade-requirements.html"
                },
                {
                    "title":"Changes in 25.3.21",
                    "href":"changes-25.3.21.html"
                },
                {
                    "title":"Changes in 25.1.13",
                    "href":"changes-25.1.13.html"
                },
                {
                    "title":"Changes in 24.4.11",
                    "href":"changes-24.4.11.html"
                },
                {
                    "title":"Changes in 24.4.9",
                    "href":"changes-24.4.9.html"
                },
                {
                    "title":"Changes in 24.3.9",
                    "href":"changes-24.3.9.html"
                },
                {
                    "title":"Changes in 24.1.15",
                    "href":"changes-24.1.15.html"
                },
                {
                    "title":"Changes in 23.3.39",
                    "href":"changes-23.3.39.html"
                },
                {
                    "title":"Changes in 23.3.30",
                    "href":"changes-23.3.29.html"
                },
                {
                    "title":"Changes in 23.1.21",
                    "href":"changes-23.1.21.html"
                },
                {
                    "title":"Changes in 22.3.52",
                    "href":"changes-22.3.52.html"
                },
                {
                    "title":"Changes in 22.3.16",
                    "href":"changes-22.3.16.html"
                },
                {
                    "title":"Changes in 22.2.12",
                    "href":"changes-22.2.12.html"
                },
                {
                    "title":"Changes in 22.1.22",
                    "href":"changes-22.1.22.html"
                },
                {
                    "title":"Changes in 22.1.16",
                    "href":"changes-22.1.16.html"
                },
                {
                    "title":"Changes in 21.2.46",
                    "href":"changes-21.2.46.html"
                },
                {
                    "title":"Changes in 21.2.29",
                    "href":"changes-21.2.29.html"
                },
                {
                    "title":"Changes in 21.2.19",
                    "href":"changes-21.2.19.html"
                },
                {
                    "title":"Changes in 21.1.12",
                    "href":"changes-21.1.12.html"
                },
                {
                    "title":"Changes in 20.3.26",
                    "href":"changes-20.3.26.html"
                },
                {
                    "title":"Changes in 20.3.17",
                    "href":"changes-20.3.17.html"
                },
                {
                    "title":"Changes in 20.2.17",
                    "href":"changes-20.2.17.html"
                },
                {
                    "title":"Changes in 20.2.16",
                    "href":"changes-20.2.16.html"
                },
                {
                    "title":"Changes in 20.1.20",
                    "href":"changes-20.1.20.html"
                },
                {
                    "title":"Changes in 20.1.16",
                    "href":"changes-20.1.16.html"
                },
                {
                    "title":"Changes in 20.1.15",
                    "href":"changes-20.1.15.html"
                },
                {
                    "title":"Changes in 19.5.30",
                    "href":"changes-19.5.30.html"
                },
                {
                    "title":"Changes in 19.5.19",
                    "href":"changes-19.5.19.html"
                },
                {
                    "title":"Changes in 19.5.16",
                    "href":"changes-19.5.16.html"
                },
                {
                    "title":"Changes in 19.3.12",
                    "href":"changes-19.3.12.html"
                },
                {
                    "title":"Changes in 19.1.10",
                    "href":"changes-19.1.10.html"
                },
                {
                    "title":"Changes in 19.1.8",
                    "href":"changes-19.1.8.html"
                },
                {
                    "title":"Changes in 18.3.11",
                    "href":"changes-18.3.11.html"
                },
                {
                    "title":"Changes in 18.3.10",
                    "href":"changes-18.3.10.html"
                },
                {
                    "title":"Changes in 18.3.9",
                    "href":"changes-18.3.9.html"
                },
                {
                    "title":"Changes in 18.1.20",
                    "href":"changes-18.1.20.html"
                },
                {
                    "title":"Changes in 18.1.16",
                    "href":"changes-18.1.16.html"
                },
                {
                    "title":"Changes in 18.1.13",
                    "href":"changes-18.1.13.html"
                }
            ]
        }
    ]
});
